@@ -448,7 +448,7 @@ int SCH_SEXPR_PARSER::parseInternalUnits()
     // Schematic internal units are represented as integers.  Any values that are
     // larger or smaller than the schematic units represent undefined behavior for
     // the system.  Limit values to the largest that can be displayed on the screen.
-    double int_limit = std::numeric_limits<int>::max() * 0.7071; // 0.7071 = roughly 1/sqrt(2)
+    constexpr double int_limit = std::numeric_limits<int>::max() * 0.7071; // 0.7071 = roughly 1/sqrt(2)
 
     return KiROUND( Clamp<double>( -int_limit, retval, int_limit ) );
 }
@@ -458,7 +458,7 @@ int SCH_SEXPR_PARSER::parseInternalUnits( const char* aExpected )
 {
     auto retval = parseDouble( aExpected ) * IU_PER_MM;
 
-    double int_limit = std::numeric_limits<int>::max() * 0.7071;
+    constexpr double int_limit = std::numeric_limits<int>::max() * 0.7071;
 
     return KiROUND( Clamp<double>( -int_limit, retval, int_limit ) );
 }
@@ -1013,15 +1013,15 @@ LIB_SHAPE* SCH_SEXPR_PARSER::parseArc()
         }
     }
 
-    arc->SetStart( startPoint );
-    arc->SetEnd( endPoint );
-
     if( hasMidPoint )
     {
-        arc->SetCenter( (wxPoint) CalcArcCenter( arc->GetStart(), midPoint, arc->GetEnd() ) );
+        arc->SetArcGeometry( startPoint, midPoint, endPoint);
     }
     else if( hasAngles )
     {
+        arc->SetStart( startPoint );
+        arc->SetEnd( endPoint );
+
         /**
          * This accounts for an oddity in the old library format, where the symbol is overdefined.
          * The previous draw (based on wxwidgets) used start point and end point and always drew
@@ -1035,6 +1035,7 @@ LIB_SHAPE* SCH_SEXPR_PARSER::parseArc()
             arc->SetStart( arc->GetEnd() );
             arc->SetEnd( temp );
         }
+
         arc->SetCenter( center );
     }
     else
