@@ -97,8 +97,8 @@ private:
 
         if( !symbol )
         {
-            Append( ID_POPUP_SCH_UNFOLD_BUS, _( "no symbol selected" ), wxEmptyString );
-            Enable( ID_POPUP_SCH_UNFOLD_BUS, false );
+            Append( ID_POPUP_SCH_SELECT_UNIT_CMP, _( "no symbol selected" ), wxEmptyString );
+            Enable( ID_POPUP_SCH_SELECT_UNIT_CMP, false );
             return;
         }
 
@@ -106,8 +106,8 @@ private:
 
         if( !symbol->GetLibSymbolRef() || symbol->GetLibSymbolRef()->GetUnitCount() < 2 )
         {
-            Append( ID_POPUP_SCH_UNFOLD_BUS, _( "symbol is not multi-unit" ), wxEmptyString );
-            Enable( ID_POPUP_SCH_UNFOLD_BUS, false );
+            Append( ID_POPUP_SCH_SELECT_UNIT_CMP, _( "symbol is not multi-unit" ), wxEmptyString );
+            Enable( ID_POPUP_SCH_SELECT_UNIT_CMP, false );
             return;
         }
 
@@ -445,7 +445,6 @@ int SCH_EDIT_TOOL::Rotate( const TOOL_EVENT& aEvent )
     int       principalItemCount = 0;  // User-selected items (as opposed to connected wires)
     wxPoint   rotPoint;
     bool      moving = false;
-    bool      connections = false;
 
     for( unsigned ii = 0; ii < selection.GetSize(); ii++ )
     {
@@ -511,6 +510,28 @@ int SCH_EDIT_TOOL::Rotate( const TOOL_EVENT& aEvent )
         }
 
         case SCH_LINE_T:
+        {
+            SCH_LINE* line = static_cast<SCH_LINE*>( head );
+
+            // Equal checks for both and neither. We need this because on undo
+            // the item will have both flags cleared, but will be selected, so it is possible
+            // for the user to get a selected line with neither endpoint selected. We
+            // set flags to make sure Rotate() works when we call it.
+            if( line->HasFlag( STARTPOINT ) == line->HasFlag( ENDPOINT ) )
+            {
+                line->SetFlags( STARTPOINT | ENDPOINT );
+                // When we allow off grid items, the rotPoint should be set to the midpoint
+                // of the line to allow rotation around the center, and the next if
+                // should become an else-if
+            }
+
+            if( line->HasFlag( STARTPOINT ) )
+                rotPoint = line->GetEndPoint();
+            else if( line->HasFlag( ENDPOINT ) )
+                rotPoint = line->GetStartPoint();
+        }
+
+            KI_FALLTHROUGH;
         case SCH_BUS_BUS_ENTRY_T:
         case SCH_BUS_WIRE_ENTRY_T:
             for( int i = 0; clockwise ? i < 3 : i < 1; ++i )
@@ -557,7 +578,6 @@ int SCH_EDIT_TOOL::Rotate( const TOOL_EVENT& aEvent )
             break;
         }
 
-        connections = head->IsConnectable();
         m_frame->UpdateItem( head, false, true );
     }
     else
@@ -636,7 +656,6 @@ int SCH_EDIT_TOOL::Rotate( const TOOL_EVENT& aEvent )
             }
         }
 
-        connections |= item->IsConnectable();
         m_frame->UpdateItem( item, false, true );
         updateItem( item, true );
     }
@@ -652,8 +671,8 @@ int SCH_EDIT_TOOL::Rotate( const TOOL_EVENT& aEvent )
         if( selection.IsHover() )
             m_toolMgr->RunAction( EE_ACTIONS::clearSelection, true );
 
-        if( connections )
-            m_frame->TestDanglingEnds();
+        m_frame->RecalculateConnections( LOCAL_CLEANUP );
+        m_frame->TestDanglingEnds();
 
         m_frame->OnModify();
     }
@@ -876,6 +895,7 @@ int SCH_EDIT_TOOL::RepeatDrawItem( const TOOL_EVENT& aEvent )
                                 Mils2iu( cfg->m_Drawing.default_repeat_offset_y ) ) );
     }
 
+    m_toolMgr->RunAction( EE_ACTIONS::addItemToSel, true, newItem );
     newItem->SetFlags( IS_NEW );
     m_frame->AddToScreen( newItem, m_frame->GetScreen() );
     m_frame->SaveCopyInUndoList( m_frame->GetScreen(), newItem, UNDO_REDO::NEWITEM, false );
@@ -892,6 +912,7 @@ int SCH_EDIT_TOOL::RepeatDrawItem( const TOOL_EVENT& aEvent )
         EE_SELECTION new_sel;
         new_sel.Add( newItem );
 
+        m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true, &new_sel );
         m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true, &new_sel );
 
         m_frame->RecalculateConnections( LOCAL_CLEANUP );
@@ -1532,7 +1553,7 @@ int SCH_EDIT_TOOL::Properties( const TOOL_EVENT& aEvent )
         break;
 
     default:                // Unexpected item
-        wxFAIL_MSG( wxString( "Cannot edit schematic item type " ) + item->GetClass() );
+        wxFAIL_MSG( wxString( wxT( "Cannot edit schematic item type " ) ) + item->GetClass() );
     }
 
     updateItem( item, true );
@@ -1566,10 +1587,10 @@ int SCH_EDIT_TOOL::ChangeTextType( const TOOL_EVENT& aEvent )
             // fix them here.
             if( text->Type() == SCH_TEXT_T )
             {
-                txt.Replace( "\n", "_" );
-                txt.Replace( "\r", "_" );
-                txt.Replace( "\t", "_" );
-                txt.Replace( " ", "_" );
+                txt.Replace( wxT( "\n" ), wxT( "_" ) );
+                txt.Replace( wxT( "\r" ), wxT( "_" ) );
+                txt.Replace( wxT( "\t" ), wxT( "_" ) );
+                txt.Replace( wxT( " " ), wxT( "_" ) );
             }
 
             // label strings are "escaped" i.e. a '/' is replaced by "{slash}"
@@ -1584,7 +1605,7 @@ int SCH_EDIT_TOOL::ChangeTextType( const TOOL_EVENT& aEvent )
             case SCH_TEXT_T:         newtext = new SCH_TEXT( position, txt );         break;
 
             default:
-                wxFAIL_MSG( wxString::Format( "Invalid text type: %d.", convertTo ) );
+                wxFAIL_MSG( wxString::Format( wxT( "Invalid text type: %d." ), convertTo ) );
                 return 0;
             }
 
@@ -1679,7 +1700,12 @@ int SCH_EDIT_TOOL::BreakWire( const TOOL_EVENT& aEvent )
         m_frame->OnModify();
         m_frame->GetCanvas()->Refresh();
 
-        m_toolMgr->RunAction( EE_ACTIONS::drag );
+        SCH_MOVE_TOOL_PARAMS params;
+
+        params.appendToLastUndo = true;
+        params.placingNewItems = false;
+
+        m_toolMgr->RunAction( EE_ACTIONS::drag, true, &params );
     }
 
     return 0;
@@ -1755,7 +1781,7 @@ int SCH_EDIT_TOOL::EditPageNumber( const TOOL_EVENT& aEvent )
     wxString pageNumber = instance.GetPageNumber();
 
     msg.Printf( _( "Enter page number for sheet path%s" ),
-                ( sheetPath.Length() > 20 ) ? "\n" + sheetPath : " " + sheetPath );
+                ( sheetPath.Length() > 20 ) ? wxT( "\n" ) + sheetPath : wxT( " " ) + sheetPath );
 
     wxTextEntryDialog dlg( m_frame, msg, _( "Edit Sheet Page Number" ), pageNumber );
 
