@@ -118,6 +118,8 @@ int SYMBOL_EDITOR_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
 
         if( evt->IsCancelInteractive() )
         {
+            m_frame->GetInfoBar()->Dismiss();
+
             if( item )
             {
                 cleanup();
@@ -183,7 +185,7 @@ int SYMBOL_EDITOR_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
                     break;
                 }
                 default:
-                    wxFAIL_MSG( "TwoClickPlace(): unknown type" );
+                    wxFAIL_MSG( wxT( "TwoClickPlace(): unknown type" ) );
                 }
 
                 // Restore cursor after dialog
@@ -216,7 +218,7 @@ int SYMBOL_EDITOR_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
                     symbol->AddDrawItem( (LIB_TEXT*) item );
                     break;
                 default:
-                    wxFAIL_MSG( "TwoClickPlace(): unknown type" );
+                    wxFAIL_MSG( wxT( "TwoClickPlace(): unknown type" ) );
                 }
 
                 item->ClearEditFlags();
