@@ -330,19 +330,19 @@ PCB_EDIT_FRAME::PCB_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     wxString strK2S = Pgm().GetExecutablePath();
 
 #ifdef __WXMAC__
-    if( strK2S.Find( "pcbnew.app" ) != wxNOT_FOUND )
+    if( strK2S.Find( wxT( "pcbnew.app" ) ) != wxNOT_FOUND )
     {
         // On macOS, we have standalone applications inside the main bundle, so we handle that here:
-        strK2S += "../../";
+        strK2S += wxT( "../../" );
     }
 
-    strK2S += "Contents/MacOS/";
+    strK2S += wxT( "Contents/MacOS/" );
 #endif
 
-    wxFileName appK2S( strK2S, "kicad2step" );
+    wxFileName appK2S( strK2S, wxT( "kicad2step" ) );
 
     #ifdef _WIN32
-    appK2S.SetExt( "exe" );
+    appK2S.SetExt( wxT( "exe" ) );
     #endif
 
     // Ensure the window is on top
@@ -581,8 +581,6 @@ void PCB_EDIT_FRAME::setupUIConditions()
                 return false;
             };
 
-    mgr->SetConditions( PCB_ACTIONS::rotateCw, ENABLE( cond.HasItems() ) );
-    mgr->SetConditions( PCB_ACTIONS::rotateCcw, ENABLE( cond.HasItems() ) );
     mgr->SetConditions( PCB_ACTIONS::group, ENABLE( SELECTION_CONDITIONS::MoreThan( 1 ) ) );
     mgr->SetConditions( PCB_ACTIONS::ungroup, ENABLE( haveAtLeastOneGroupCond ) );
     mgr->SetConditions( PCB_ACTIONS::lock, ENABLE( cond.HasItems() ) );
@@ -726,12 +724,11 @@ void PCB_EDIT_FRAME::setupUIConditions()
                         ENABLE( SELECTION_CONDITIONS::OnlyType( PCB_FOOTPRINT_T ) ) );
 
 
-    SELECTION_CONDITION singleZoneCond = SELECTION_CONDITIONS::Count( 1 ) &&
-                                         SELECTION_CONDITIONS::OnlyTypes( GENERAL_COLLECTOR::Zones );
+    SELECTION_CONDITION singleZoneCond = SELECTION_CONDITIONS::Count( 1 )
+                                    && SELECTION_CONDITIONS::OnlyTypes( GENERAL_COLLECTOR::Zones );
 
-    SELECTION_CONDITION zoneMergeCond = SELECTION_CONDITIONS::MoreThan( 1 ) &&
-                                        PCB_SELECTION_CONDITIONS::SameNet( true ) &&
-                                        PCB_SELECTION_CONDITIONS::SameLayer();
+    SELECTION_CONDITION zoneMergeCond = SELECTION_CONDITIONS::MoreThan( 1 )
+                                    && SELECTION_CONDITIONS::OnlyTypes( GENERAL_COLLECTOR::Zones );
 
     mgr->SetConditions( PCB_ACTIONS::zoneDuplicate, ENABLE( singleZoneCond ) );
     mgr->SetConditions( PCB_ACTIONS::drawZoneCutout, ENABLE( singleZoneCond ) );
@@ -927,7 +924,7 @@ void PCB_EDIT_FRAME::doCloseWindow()
     if( !fn.IsOk() || !fn.IsDirWritable() )
         fn.SetPath( wxFileName::GetTempDir() );
 
-    wxLogTrace( traceAutoSave, "Deleting auto save file <" + fn.GetFullPath() + ">" );
+    wxLogTrace( traceAutoSave, wxT( "Deleting auto save file <" ) + fn.GetFullPath() + wxT( ">" ) );
 
     // Remove the auto save file on a normal close of Pcbnew.
     if( fn.FileExists() && !wxRemoveFile( fn.GetFullPath() ) )
@@ -988,24 +985,33 @@ void PCB_EDIT_FRAME::ShowBoardSetupDialog( const wxString& aInitialPage )
 
         Kiway().CommonSettingsChanged( false, true );
 
-        const PCB_DISPLAY_OPTIONS& opts = GetDisplayOptions();
+        static LSET maskAndPasteLayers = LSET( 4, F_Mask, F_Paste, B_Mask, B_Paste );
 
-        if( opts.m_ShowTrackClearanceMode || opts.m_DisplayPadClearance )
-        {
-            // Update clearance outlines
-            GetCanvas()->GetView()->UpdateAllItemsConditionally( KIGFX::REPAINT,
-                    [&]( KIGFX::VIEW_ITEM* aItem ) -> bool
+        bool maskOrPasteVisible = ( GetBoard()->GetVisibleLayers() & maskAndPasteLayers ).any();
+        bool padClearancesVisible = GetDisplayOptions().m_DisplayPadClearance;
+        bool trackClearancesVisible = GetDisplayOptions().m_ShowTrackClearanceMode
+                                    == PCB_DISPLAY_OPTIONS::SHOW_TRACK_CLEARANCE_WITH_VIA_ALWAYS;
+
+        GetCanvas()->GetView()->UpdateAllItemsConditionally( KIGFX::REPAINT,
+                [&]( KIGFX::VIEW_ITEM* aItem ) -> bool
+                {
+                    if( dynamic_cast<PCB_TRACK*>( aItem ) )
                     {
-                        PCB_TRACK* track = dynamic_cast<PCB_TRACK*>( aItem );
-                        PAD*       pad = dynamic_cast<PAD*>( aItem );
+                        return trackClearancesVisible;
+                    }
+                    else if( dynamic_cast<PAD*>( aItem ) )
+                    {
+                        return padClearancesVisible || maskOrPasteVisible;
+                    }
+                    else if( dynamic_cast<EDA_TEXT*>( aItem ) )
+                    {
+                        EDA_TEXT* text = dynamic_cast<EDA_TEXT*>( aItem );
 
-                        // PCB_TRACK is the base class of PCB_VIA and PCB_ARC so we don't need
-                        // to check them independently
+                        return text->HasTextVars();
+                    }
 
-                        return ( track && opts.m_ShowTrackClearanceMode )
-                                || ( pad && opts.m_DisplayPadClearance );
-                    } );
-        }
+                    return false;
+                } );
 
         GetCanvas()->Refresh();
 
@@ -1247,7 +1253,8 @@ void PCB_EDIT_FRAME::ShowChangedLanguage()
     pane_info.Caption( _( "Appearance" ) );
     m_auimgr.Update();
 
-    m_appearancePanel->OnBoardChanged();
+    m_appearancePanel->OnLanguageChanged();
+    m_selectionFilterPanel->OnLanguageChanged();
 }
 
 
@@ -1289,7 +1296,7 @@ void PCB_EDIT_FRAME::OnModify( )
 
     Update3DView( true, GetDisplayOptions().m_Live3DRefresh );
 
-    if( !GetTitle().StartsWith( "*" ) )
+    if( !GetTitle().StartsWith( wxT( "*" ) ) )
         UpdateTitle();
 
     m_ZoneFillsDirty = true;
@@ -1437,23 +1444,18 @@ void PCB_EDIT_FRAME::ToPlotter( int aID )
     case ID_GEN_PLOT_PS:
         plotSettings.SetFormat( PLOT_FORMAT::POST );
         break;
-    case ID_GEN_PLOT:        /* keep the previous setup */                   break;
+    case ID_GEN_PLOT:
+        /* keep the previous setup */
+        break;
     default:
-        wxFAIL_MSG( "ToPlotter(): unexpected plot type" ); break;
+        wxFAIL_MSG( wxT( "ToPlotter(): unexpected plot type" ) ); break;
         break;
     }
 
     SetPlotSettings( plotSettings );
 
-    // Force rebuild the dialog if currently open because the old dialog can be not up to date
-    // if the board (or units) has changed
-    wxWindow* dlg =  wxWindow::FindWindowByName( DLG_WINDOW_NAME );
-
-    if( dlg )
-        dlg->Destroy();
-
-    dlg = new DIALOG_PLOT( this );
-    dlg->Show( true );
+    DIALOG_PLOT dlg( this );
+    dlg.ShowQuasiModal(  );
 }
 
 
@@ -1534,7 +1536,7 @@ bool PCB_EDIT_FRAME::FetchNetlistFromSchematic( NETLIST& aNetlist,
         Raise();
 
         // Do not translate extra_info strings.  These are for developers
-        wxString extra_info = e.Problem() + " : " + e.What() + " at " + e.Where();
+        wxString extra_info = e.Problem() + wxT( " : " ) + e.What() + wxT( " at " ) + e.Where();
 
         DisplayErrorMessage( this, _( "Received an error while reading netlist.  Please "
                                       "report this issue to the KiCad team using the menu "
